Manage observing environment for the Vera Rubin Observatory Control System.
Changelog
[0.2.5]
- Add ts_config_scheduler to the list of repositories.
[0.2.4]
- Fix missing argument in the setup file.
- Remove unnecessary imports.
[0.2.3]
- Add ts_auxtel_standardscripts and ts_maintel_standardscripts to the list of managed packages.
- Add new create_setup_file method to ManageObsEnv that creates the bash file to setup the obs-env. This is then called in the Setup action of manage-obs-env.
[0.2.2]
- Fix issue with summary log for Spectractor.
[0.2.1]
- Fix issues with summary log for summit_utils.
[0.2.0]
- Add feature to log actions to Sasquatch database.
- Add all config packages to the list of managed packages.